@@ -56,6 +56,34 @@ Col<eT>::Col(const uword in_n_rows, const uword in_n_cols)
 
 
 
+template<typename eT>
+template<typename fill_type>
+inline
+Col<eT>::Col(const uword in_n_elem, const fill::fill_class<fill_type>& f)
+  : Mat<eT>(arma_vec_indicator(), in_n_elem, 1, 1)
+  {
+  arma_extra_debug_sigprint();
+  
+  (*this).fill(f);
+  }
+
+
+
+template<typename eT>
+template<typename fill_type>
+inline
+Col<eT>::Col(const uword in_n_rows, const uword in_n_cols, const fill::fill_class<fill_type>& f)
+  : Mat<eT>(arma_vec_indicator(), 0, 0, 1)
+  {
+  arma_extra_debug_sigprint();
+  
+  Mat<eT>::init_warm(in_n_rows, in_n_cols);
+  
+  (*this).fill(f);
+  }
+
+
+
 //! construct a column vector from specified text
 template<typename eT>
 inline
@@ -207,6 +235,32 @@ Col<eT>::operator=(const std::vector<eT>& x)
     return *this;
     }
   
+  
+  
+  template<typename eT>
+  inline
+  Col<eT>::Col(Col<eT>&& X)
+    : Mat<eT>(arma_vec_indicator(), 1)
+    {
+    arma_extra_debug_sigprint();
+    
+    (*this).steal_mem(X);
+    }
+  
+  
+  
+  template<typename eT>
+  inline
+  const Col<eT>&
+  Col<eT>::operator=(Col<eT>&& X)
+    {
+    arma_extra_debug_sigprint();
+    
+    (*this).steal_mem(X);
+    
+    return *this;
+    }
+  
 #endif
 
 
@@ -221,7 +275,9 @@ Col<eT>::Col(const SpCol<eT>& X)
   arrayops::inplace_set(Mat<eT>::memptr(), eT(0), X.n_elem);
 
   for(typename SpCol<eT>::const_iterator it = X.begin(); it != X.end(); ++it)
+    {
     at(it.row()) = (*it);
+    }
   }
 
 
@@ -240,6 +296,20 @@ Col<eT>::operator=(const eT val)
 
 
 
+template<typename eT>
+inline
+const Col<eT>&
+Col<eT>::operator=(const Col<eT>& X)
+  {
+  arma_extra_debug_sigprint();
+  
+  Mat<eT>::operator=(X);
+  
+  return *this;
+  }
+
+
+
 template<typename eT>
 template<typename T1>
 inline
@@ -496,6 +566,30 @@ Col<eT>::subvec(const uword in_row1, const uword in_row2) const
 
 
 
+template<typename eT>
+arma_inline
+subview_col<eT>
+Col<eT>::rows(const span& row_span)
+  {
+  arma_extra_debug_sigprint();
+  
+  return subvec(row_span);
+  }
+
+
+
+template<typename eT>
+arma_inline
+const subview_col<eT>
+Col<eT>::rows(const span& row_span) const
+  {
+  arma_extra_debug_sigprint();
+  
+  return subvec(row_span);
+  }
+
+
+
 template<typename eT>
 arma_inline
 subview_col<eT>
@@ -809,9 +903,10 @@ Col<eT>::fixed<fixed_n_elem>::fixed(const fixed<fixed_n_elem>& X)
   {
   arma_extra_debug_sigprint_this(this);
   
-  eT* dest = (use_extra) ? mem_local_extra : Mat<eT>::mem_local;
+        eT* dest = (use_extra) ?   mem_local_extra : Mat<eT>::mem_local;
+  const eT* src  = (use_extra) ? X.mem_local_extra :        X.mem_local;
   
-  arrayops::copy( dest, X.mem, fixed_n_elem );
+  arrayops::copy( dest, src, fixed_n_elem );
   }
 
 
@@ -829,6 +924,24 @@ Col<eT>::fixed<fixed_n_elem>::fixed(const subview_cube<eT>& X)
 
 
 
+template<typename eT>
+template<uword fixed_n_elem>
+template<typename fill_type>
+inline
+Col<eT>::fixed<fixed_n_elem>::fixed(const fill::fill_class<fill_type>&)
+  : Col<eT>( arma_fixed_indicator(), fixed_n_elem, ((use_extra) ? mem_local_extra : Mat<eT>::mem_local) )
+  {
+  arma_extra_debug_sigprint_this(this);
+  
+  if(is_same_type<fill_type, fill::fill_zeros>::yes)  (*this).zeros();
+  if(is_same_type<fill_type, fill::fill_ones >::yes)  (*this).ones();
+  if(is_same_type<fill_type, fill::fill_eye  >::yes)  (*this).eye();
+  if(is_same_type<fill_type, fill::fill_randu>::yes)  (*this).randu();
+  if(is_same_type<fill_type, fill::fill_randn>::yes)  (*this).randn();
+  }
+
+
+
 template<typename eT>
 template<uword fixed_n_elem>
 template<typename T1>
@@ -1023,6 +1136,24 @@ Col<eT>::fixed<fixed_n_elem>::operator=(const subview_cube<eT>& X)
 
 
 
+template<typename eT>
+template<uword fixed_n_elem>
+arma_inline
+const Col<eT>&
+Col<eT>::fixed<fixed_n_elem>::operator=(const fixed<fixed_n_elem>& X)
+  {
+  arma_extra_debug_sigprint();
+  
+        eT* dest = (use_extra) ?   mem_local_extra : Mat<eT>::mem_local;
+  const eT* src  = (use_extra) ? X.mem_local_extra :        X.mem_local;
+  
+  arrayops::copy( dest, src, fixed_n_elem );
+  
+  return *this;
+  }
+
+
+
 template<typename eT>
 template<uword fixed_n_elem>
 arma_inline
