@@ -21,23 +21,38 @@ op_dot::direct_dot_arma(const uword n_elem, const eT* const A, const eT* const B
   {
   arma_extra_debug_sigprint();
   
-  eT val1 = eT(0);
-  eT val2 = eT(0);
-  
-  uword i, j;
-  
-  for(i=0, j=1; j<n_elem; i+=2, j+=2)
+  #if (__FINITE_MATH_ONLY__ > 0)
     {
-    val1 += A[i] * B[i];
-    val2 += A[j] * B[j];
+    eT val = eT(0);
+    
+    for(uword i=0; i<n_elem; ++i)
+      {
+      val += A[i] * B[i];
+      }
+    
+    return val;
     }
-  
-  if(i < n_elem)
+  #else
     {
-    val1 += A[i] * B[i];
+    eT val1 = eT(0);
+    eT val2 = eT(0);
+    
+    uword i, j;
+    
+    for(i=0, j=1; j<n_elem; i+=2, j+=2)
+      {
+      val1 += A[i] * B[i];
+      val2 += A[j] * B[j];
+      }
+    
+    if(i < n_elem)
+      {
+      val1 += A[i] * B[i];
+      }
+    
+    return val1 + val2;
     }
-  
-  return val1 + val2;
+  #endif
   }
 
 
@@ -634,4 +649,36 @@ op_cdot::apply_proxy(const T1& X, const T2& Y)
 
 
 
+template<typename T1, typename T2>
+arma_hot
+inline
+typename promote_type<typename T1::elem_type, typename T2::elem_type>::result
+op_dot_mixed::apply(const T1& A, const T2& B)
+  {
+  arma_extra_debug_sigprint();
+  
+  typedef typename T1::elem_type in_eT1;
+  typedef typename T2::elem_type in_eT2;
+  
+  typedef typename promote_type<in_eT1, in_eT2>::result out_eT;
+  
+  const Proxy<T1> PA(A);
+  const Proxy<T2> PB(B);
+  
+  const uword N = PA.get_n_elem();
+  
+  arma_debug_check( (N != PB.get_n_elem()), "dot(): objects must have the same number of elements" );
+  
+  out_eT acc = out_eT(0);
+  
+  for(uword i=0; i < N; ++i)
+    {
+    acc += upgrade_val<in_eT1,in_eT2>::apply(PA[i]) * upgrade_val<in_eT1,in_eT2>::apply(PB[i]);
+    }
+  
+  return acc;
+  }
+
+
+
 //! @}
